# nightscout dash
A dashboard to display glucose statistics from nightscout implementation.
Nightscout is compatabile with freestyle libre devices with the [Juggluco](https://github.com/j-kaltes/Juggluco) mobile app.

## Usage

## Cheaper continuous blood glucose monitors.
Freestyle libre devices in the UK cost about three times the price of cheaper aidex devices which can be readily obtained through alibana and aliexpress.
In the US CGMs can be massivley overpriced. You can likely obtain an identical device on aliexpress for considerably cheaper.

Unfortunately the aidex 2 device (but not aidex 1) rqeuires a chinese phone number. I may reverse engineer these devices in the future to makes these devices
more accessible and increase access.
